@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
 our $DATE = '2015-04-07'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -507,10 +507,12 @@ sub _process_script {
                 push @content, "\n";
 
                 # now list the options for each subcommand
-                for my $scn (@sc_names) {
-                    push @content, "=head2 For subcommand '$scn'\n\n";
+                for my $sc_name (@sc_names) {
+                    my $sc_spec = $cli->{subcommands}{$sc_name};
+                    next if $sc_spec->{is_alias};
+                    push @content, "=head2 For subcommand '$sc_name'\n\n";
                     $param2opts = $self->_list_config_params(
-                        $clidocdata{$scn},
+                        $clidocdata{$sc_name},
                         sub { !('common' ~~ @{ $_[0]->{tags} // []}) });
                     for (sort keys %$param2opts) {
                         push @content, " $_ (see $param2opts->{$_})\n";
@@ -603,7 +605,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.37 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-07.
+This document describes version 0.38 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-07.
 
 =head1 SYNOPSIS
 
